Provedba procjene rizika s pomoću alata OiRA | OiRA

Teme

# Provedba procjene rizika s pomoću alata OiRA

## Pokretanje nove sesije

Da biste pokrenuli novu procjenu rizika, kliknite na poveznicu „Pokrenite novu sesiju”.

## Otvaranje procjene rizika

Nakon što pokrenete procjenu rizika, u svakom je trenutku možete dohvatiti na nadzornoj ploči, u zaglavlju „Moje procjene rizika”. Ondje možete pokrenuti i novu procjenu rizika.

Nadzorna ploča.

## Kretanje zaslonom procjene rizika

Svaka procjena rizika sastoji se od nekoliko koraka. Oni se prikazuju u glavnom izborniku s lijeve strane zaslona:

- „Priprema”
- „Sudjelovanje”
- „Prepoznavanje + procjena”
- „Plan mjera”
- „Završni dokumenti”
- „Status”.

Ovisno o odlukama koje su donijeli partneri za alat OiRA ili programeri alata OiRA, struktura svakog alata može se razlikovati. U nekim alatima korak prepoznavanja i procjene rizika uključuje plan mjera. U tom slučaju, u izborniku slijeva prikazuju se sljedeći koraci:

- „Priprema”
- „Sudjelovanje”
- „Procjena”
- „Završni dokumenti”
- „Status”.

## Priprema

Korak „Priprema” prvi je korak svake sesije/alata. U tom koraku morate navesti naslov procjene rizika kako biste kasnije mogli lakše razlikovati više procjena rizika koje ste proveli s pomoću tog alata.

Klikom na poveznicu „Saznajte više o ovom alatu…” pristupate dodatnim informacijama o odabranom alatu i stranama koje su sudjelovale u njegovoj izradi.

Nakon što kliknete na opciju „Pokrenite”, možda ćete trebati odgovoriti na dodatna pitanja, ovisno o alatu koji upotrebljavate. Taj uvodni zaslon s pitanjima za profiliranje prikazuje se samo u alatima u kojima postoji ta opcija.

Na njemu imate na raspolaganju sljedeće opcije:

- Odaberite ili preskočite situacije ovisno o tome odnose li se na vašu poslovnu djelatnost. Prema potrebi odaberite opciju „Da”.
- Navedite više poslovnih jedinica, podružnica, trgovina itd. Povezani rizici ponovit će se za svaki unos.

Zaslon „Profil” u okviru koraka „Priprema”

Korak pripreme vrlo je važan jer se u okviru njega precizno definira vrsta djelatnosti i povezani rizici s kojima se suočava vaše poduzeće. Nakon što kliknete na opciju „Spremi i nastavi”, sustav će vas prebaciti na sljedeći odjeljak, „Sudjelovanje”.

Napomena: U mnogim alatima značajka pitanja za profiliranje nije dostupna i ne upotrebljava se za usmjeravanje rada alata. U tom se slučaju ovaj zaslon automatski preskače.

## Sudjelovanje

Ovaj je korak podsjetnik na važnost sudjelovanja radnika. U okviru njega iznose se različiti načini za osiguravanje aktivnog sudjelovanja radnika. Ovdje možete preuzeti ili ispisati sadržaj procjene rizika kako biste ga podijelili sa svojim radnicima/zaposlenicima. Na taj način osiguravate da radnici mogu pridonijeti procjeni situacije na njihovu radnom mjestu.

## Procjena

U ovom koraku utvrdit ćete opasnosti i probleme koji se odnose na vaše poduzeće.

Napomena: Ovisno o načinu na koji je partner za alat OiRA konfigurirao alat, korak „Plan mjera” (vidjeti u nastavku) možda je integriran u ovaj zaslon. U tom slučaju, cijeli se korak naziva „Procjena”, a elementi opisani u koraku „Plan mjera” prikazat će se u koraku za prepoznavanje i procjenu za svaki rizik.

Prepoznavanje i procjena.

S lijeve strane zaslona, u nastavku koraka „Prepoznavanje + procjena” / „Procjena”, prikazuju se teme/moduli uvršteni u alat. Tema koju trenutačno pregledavate bit će istaknuta.

### Prepoznavanje

Za svaki rizik morate utvrditi odnosi li se tvrdnja u kojoj se opisuje željena situacija na vaše poduzeće. Možete odgovoriti na sljedeći način:

- „Da”: ako na tvrdnju odgovorite „da”, ne morate poduzeti nikakve dodatne korake jer ste procijenili da određeni rizik ne postoji.
- „Ne”: ako na tvrdnju odgovorite „ne”, morate poduzeti dodatne korake. Od vas će se zatražiti da utvrdite određene mjere.
- „Nije primjenjivo”: u okviru nekih tvrdnji o rizicima možete odabrati opciju „Nije primjenjivo” ako se određeni rizik ne odnosi na vaše poduzeće/organizaciju.

Ispod svake izjave navedene su dodatne informacije o određenom riziku:

- „Informacije”: riječ je o kratkom opisu, katkad uz popratne slike, u kojem su navedene dodatne pojedinosti o riziku.
- „Propisi i dodatne informacije”: ovdje su navedene dodatne informacije o riziku, kao što su upućivanja na zakonodavne akte i propise. U tom su odjeljku ponekad dostupni dokumenti za daljnje proučavanje.
- „Komentari”: ovdje možete navesti svoje komentare koji će se prikazati u izvješću na kraju procjene.

Nakon što odgovorite na tvrdnju o riziku i nastavite, u izborniku slijeva prikazuju se obojeni simboli koji označavaju da ste:

- odgovorili pozitivno (zelena kvačica);
- odgovorili negativno (crveni križić);
- odgodili odgovor (narančasti upitnik).

Uz pitanja na koja niste odgovorili i dalje se prikazuje sivi simbol.

### Procjena

U ovom koraku procjenjujete prioritet rizika koji ste utvrdili.

Procjena rizika.

Napomena: U nekim se alatima OiRA procjena ne prikazuje. To ovisi o načinu na koji je nacionalni partner ili programer alata OiRA postavio određeni alat.

Ako ste utvrdili da rizik postoji (označeno crvenim križićem), prikazat će se odjeljak za procjenu. Ovisno o metodi procjene koja je postavljena za svaki rizik, od vas će se zatražiti da učinite sljedeće:

- procijenite prioritet: visoko, srednje ili nisko;

Određivanje prioriteta rizika.

ILI

- odgovorite na nekoliko pitanja o učestalosti, ozbiljnosti i vjerojatnosti rizika kako bi se prioritet procijenio na temelju vaših odgovora.

Postavljanje varijabli za rizik.

### Prioritetni rizici koje određuje sektor

Nacionalni partner ili programer alata koji je izradio određeni alat OiRA neke je rizike smatrao vrlo važnima. Takve „prioritetne rizike” ne trebate procijeniti jer će se prioritet za njih automatski postaviti na varijablu „visoko”.

Prioritetni rizici.

### Prilagođeni rizici

Nakon što u koraku „Prepoznavanje + procjena” / „Procjena” odgovorite na sve teme povezane s rizicima, otvorit će vam se neobvezna tema „Ostali rizici”. Ovdje s pomoću gumba „Dodajte uobičajeni rizik” možete dodati svoje unose.

Ako u alatu nisu navedeni rizici koji postoje na vašem radnom mjestu ili u vašem poduzeću, ovdje ih trebate dodati. Te rizike u cijelosti možete sami definirati/formulirati.

Uobičajeni rizici.

„Uobičajeni rizik” funkcionira na vrlo sličan način kao rizici navedeni u okviru alata OiRA, ali trebate sastaviti vlastiti tekst. Taj bi tekst trebao biti barem u obliku kratke tvrdnje u kojoj se opisuje problematična situacija, a može se dodati i dulji opis. Možete i učitati sliku kako biste pobliže dočarali određenu situaciju.

Kao i s ostalim rizicima, trebate navesti postoji li određeni rizik ili ne. To vam omogućuje da označite uobičajene rizike koje ste uspješno obradili, ali i da ih zadržite u procjeni rizika kako biste ih dokumentirali.

Možete dodati neograničen broj uobičajenih rizika.

Dodajte uobičajeni rizik.

## Plan mjera

U ovom koraku određujete mjere koje želite provesti kako biste uklonili ili ublažili rizike koje ste prethodno utvrdili.

Napomena: Kao što je već navedeno, plan mjera prikazan je kao zaseban korak u izborniku slijeva ili se prikazuje u okviru svakog utvrđenog rizika. U potonjem slučaju korak u izborniku naziva se „Procjena”, a obuhvaća i tvrdnje o rizicima i opcije za odabir odgovora.

Verzija koja vam je dostupna ovisi o odlukama koje je donio nacionalni partner za alat OiRA ili programer alata OiRA.

### Integrirani plan mjera

Integrirani plan mjera.

Ako na pitanje odgovorite „ne”, na stranici će se otvoriti modul plana mjera, pod naslovom „Mjere”.

Možete odabrati mjere s popisa mjera predloženog u alatu i definirati svoje mjere.

### Zasebni plan mjera

Ako je plan mjera dostupan u zasebnom koraku, moći ćete mu pristupiti u izborniku s lijeve strane.

Kliknite na gumb „Kreiraj plan mjera” da biste započeli izradu svojeg plana.

U koraku za izradu plana mjera, u izborniku slijeva sada se prikazuju samo rizici označeni za poduzimanje daljnjih koraka jer je za ostale rizike utvrđeno da ne postoje.

Za svaki rizik za koji tijekom postupka procjene odgovorite „ne” i za prioritetne rizike (neovisno o tome jeste li za njih dali pozitivan ili negativan odgovor) od vas će se zatražiti da definirate mjere.

Rizik u planu mjera.

Možete odabrati mjere s popisa mjera predloženog u alatu ili definirati svoje mjere.

#### Dodavanje vlastite mjere

Dodajte dodatnu mjeru.

Da biste započeli s definiranjem preventivne mjere, upotrijebite gumb „Dodajte mjeru”. Trebali biste:

- opisati opći pristup koji će se primijeniti kako bi se uklonio ili smanjio određeni rizik;
- navesti razinu stručne osposobljenosti i/ili nužne zahtjeve (npr. ovdje možete dodatno napomenuti je li za suzbijanje određenog rizika nužno posebno osposobljavanje ili znanje vanjskih stručnjaka) (nije obvezno);
- unijeti informacije o osobi zaduženoj za provedbu;
- odrediti proračun, prema potrebi;
- utvrditi datum početka i planirani datum završetka provedbe određene mjere (nije obvezno).

Možete dodati neograničen broj mjera.

#### Dodavanje predloženih mjera

Ovisno o načinu na koji je partner za alat OiRA ili programer alata OiRA postavio određeni alat, za pojedinačne rizike dostupne su unaprijed definirane mjere. Da biste odabrali jednu ili više unaprijed definiranih mjera, kliknite na gumb „Odaberite predložene mjere”.

Otvara se skočni izbornik u kojem su prikazane sve predložene mjere. Kliknite na gumb „Dodaj” da biste odabrali mjere koje želite upotrijebiti.

Unaprijed definirane mjere zatim će se navesti u vašem planu mjera. Opis postupka nije moguće mijenjati, a ostale rubrike (odgovornost, proračun, datumi) možete, i trebali biste, sami ispuniti.

Dodavanje predloženih mjera.

U svakom trenutku možete ponovno izbrisati i predložene mjere i mjere koje ste sami definirali.

## Završni dokumenti

Nakon što dovršite plan mjera, možete izraditi izvješće.

Ako želite ostaviti napomenu koja će se uvrstiti u izvješće, ovdje unesite tekst i spremite ga.

Komentari uz izvješće.

Kliknite ovdje da biste saznali više o različitim izvješćima i načinima na koje ih možete upotrebljavati.

## Status

Na malom tortnom grafikonu u izborniku slijeva prikazan je vaš napredak u okviru alata.

U odjeljku o statusu prikazuje se pregled svih rizika koje ste utvrdili, svih rizika čijem ste rješavanju pristupili tako što ste odredili mjere i svih rizika/tvrdnji na koje još niste odgovorili.

Stranica sa statusom.

Kad otvorite zaslon odjeljka o statusu, prikazat će vam se koliko ste napredovali u svakom modulu. To vam može pomoći da zabilježite područja u kojima još trebate procijeniti rizike ili odrediti mjere za rješavanje rizika koje ste utvrdili.

Scroll to top Load toolbar…
Back

## 3-carryig-out-a-risk-assessment.md

Više

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More